==> galaxeus_lib-0.0.56.tar.gz: lib/args/args.dart <==
// ignore_for_file: non_constant_identifier_names

import 'package:galaxeus_lib/extension/regexp.dart';

class Args {
  List<String> arguments = [];

  Args(List<String> args) {
    arguments.addAll(args);
  }

  factory Args.fromString(String arg) {
    List<String> args = [];
    String state_data = "";

    for (var i = 0; i < arg.length; i++) {
      String loop_data = arg[i];
      if (state_data.isNotEmpty) {
        void addStateData(String end_data, int index) {
          for (var index_state = index;
              index_state < arg.length;
              index_state++) {
            if (index_state == arg.length - 1) {
              state_data += arg[index_state];
              i = index_state;
              args.add(state_data);
              state_data = "";
              break;
            } else if (RegExp(end_data, caseSensitive: false)
                .hashData(arg[index_state])) {
              if (end_data == " ") {
              } else {
                state_data += arg[index_state];
              }
              i = index_state;
              args.add(state_data);
              state_data = "";
              break;
            } else {
              state_data += arg[index_state];
            }
          }
        }

        while (true) {
          if (state_data.isEmpty) {
            break;
          }
          String state_data_first = state_data[0];
          if (RegExp("([-+=])", caseSensitive: false)
              .hashData(state_data_first)) {
            addStateData(" ", i);
            break;
          } else if (RegExp("([\"'`])", caseSensitive: false)
              .hashData(state_data_first)) {
            addStateData(state_data_first, i);
            break;
          } else {
            addStateData(" ", i);
            break;
          }
        }
      } else {
        if (loop_data != " ") {
          state_data += loop_data;
        }
      }
    }
    return Args(args);
  }

  String? operator [](String name) {
    for (var i = 0; i < arguments.length; i++) {
      String arg = arguments[i];
      if (arg == name) {
        try {
          return arguments[i + 1];
        } catch (e) {
          return null;
        }
      }
    }
    return null;
  }

  void operator []=(String key, String value) {
    int? index = findIndex(key);
    if (index != null) {
      try {
        arguments[index + 1] = value;
      } catch (e) {
        arguments.add(value);
      }
    } else {
      arguments.addAll([
        key,
        value,
      ]);
    }
  }

  int? findIndex(String name) {
    for (var i = 0; i < arguments.length; i++) {
      String arg = arguments[i];
      if (arg == name) {
        try {
          return i;
        } catch (e) {
          return null;
        }
      }
    }
    return null;
  }
}

==> galaxeus_lib-0.0.89.tar.gz: lib/args/args.dart <==
// ignore_for_file: non_constant_identifier_names

import 'package:galaxeus_lib/extension/extension.dart';
import 'package:galaxeus_lib/extension/regexp.dart';

class Args {
  List<String> arguments = [];

  Args(List<String> args) {
    arguments.addAll(args);
  }

  factory Args.fromString(String arg) {
    List<String> args = [];
    String state_data = "";

    for (var i = 0; i < arg.length; i++) {
      String loop_data = arg[i];
      if (state_data.isNotEmpty) {
        void addStateData(String end_data, int index) {
          for (var index_state = index;
              index_state < arg.length;
              index_state++) {
            if (index_state == arg.length - 1) {
              state_data += arg[index_state];
              i = index_state;
              args.add(state_data);
              state_data = "";
              break;
            } else if (RegExp(end_data, caseSensitive: false)
                .hashData(arg[index_state])) {
              if (end_data == " ") {
              } else {
                state_data += arg[index_state];
              }
              i = index_state;
              args.add(state_data);
              state_data = "";
              break;
            } else {
              state_data += arg[index_state];
            }
          }
        }

        while (true) {
          if (state_data.isEmpty) {
            break;
          }
          String state_data_first = state_data[0];
          if (RegExp("([-+=])", caseSensitive: false)
              .hashData(state_data_first)) {
            addStateData(" ", i);
            break;
          } else if (RegExp("([\"'`])", caseSensitive: false)
              .hashData(state_data_first)) {
            addStateData(state_data_first, i);
            break;
          } else {
            addStateData(" ", i);
            break;
          }
        }
      } else {
        if (loop_data != " ") {
          state_data += loop_data;
        }
      }
    }
    return Args(args);
  }

  bool contains(Object? key) {
    if (key is String) {
      return arguments.contains(key);
    }
    if (key is List<String>) {
      for (var i = 0; i < key.length; i++) {
        String key_data = key[i];
        if (arguments.contains(key_data)) {
          return true;
        }
      }
    }
    return false;
  }

  String? operator [](Object? key) {
    if (key is String) {
      for (var i = 0; i < arguments.length; i++) {
        String arg = arguments[i];
        if (arg == key) {
          try {
            return arguments[i + 1];
          } catch (e) {
            return null;
          }
        }
      }
    }
    if (key is int) {
      try {
        return arguments[key];
      } catch (e) {
        return null;
      }
    }
    if (key is List<String>) {
      for (var i = 0; i < key.length; i++) {
        String data = key[i];

        String? args_data = this[data];

        if (args_data != null) {
          return args_data;
        }
      }
    }
    return null;
  }

  String? after(Object? data) {
    if (data is int) {
      return this[data + 1];
    }
    if (data is String) {
      return this[data];
    }
    return null;
  }

  String? before(Object? data) {
    if (data is int) {
      return this[data - 1];
    }
    if (data is String) {
      return this[findIndex(data) ?? 0 - 1];
    }
    return null;
  }

  void operator []=(String key, String value) {
    int? index = findIndex(key);
    if (index != null) {
      try {
        arguments[index + 1] = value;
      } catch (e) {
        arguments.add(value);
      }
    } else {
      arguments.addAll([
        key,
        value,
      ]);
    }
  }

  int? findIndex(String name) {
    for (var i = 0; i < arguments.length; i++) {
      String arg = arguments[i];
      if (arg == name) {
        try {
          return i;
        } catch (e) {
          return null;
        }
      }
    }
    return null;
  }
}
